RelationOverride class

Configuration for relation overrides on a specific relation

Constructors

RelationOverride({bool enabled = true, String? table, String? foreignKey, String? referencedColumn})
const
RelationOverride.disabled()
Creates a disabled relation override
factory

Properties

enabled bool
Whether this relation should be embedded
final
foreignKey String?
Override the foreign key column name
final
hashCode int
The hash code for this object.
no setterinherited
referencedColumn String?
Override the referenced column name
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
table String?
Override the target table name
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited